==> epaper-2.1.tgz: epaper-2.1/mailout.php <==
<?php
 require("config.php");
 require("auth.php");
 $all=file($PAPERFILE);//ŪiҦɮ
 $gball=file($GBPAPERFILE);//ŪiҦɮ
 /*****oѼ ********/
 $USER=$_REQUEST["USER"];
 $RETURNID=$_REQUEST["RETURNID"];
 $SUBJ=$_REQUEST["SUBJ"];
 $sfile=(int) $_REQUEST["sfile"];
 $message=$_REQUEST["message"];
 $userfile=$_FILES['userfile']['tmp_name'];
 /**************** O}lɶ *************/
 $fp=fopen($LOGFILE,"a");
 $DAYTIME=date("Y/m/d H:i:s");
 $MSG="$DAYTIME $PHP_AUTH_USER }loe $USER qlI\n"; 
 fputs($fp,$MSG);
 fclose($fp);
 $outfile=$PAPERBASEDIR.$USER."/MSG";
 $gboutfile=$AUTOCONV." > ".$PAPERBASEDIR.$USER."/GBMSG";
 /*********BzH **********************/
 if ($sfile==1 && is_readable($userfile)) 
   {
	$userfile_name=$_FILES['userfile']['name'];
	echo "HX $userfile_name <br>";
	$message=join("",file($userfile));
   }
 if (strlen(trim($message))==0)
  {
	echo "~ISeI<br>\n";
	exit;
  }
  $message=str_replace("\"","\"",$message);

 /********* }leH ********************/
 $fp=fopen($outfile,"w");
 $gbfp=popen($gboutfile,"w");
 if ($fp)
 {
	fputs($fp,"{$SENDID}\n{$RETURNID}\n{$SUBJ}\n{$message}");
	fclose($fp);
	/****XGBX******/
	$message=str_replace($MAIN_URL,$GB_URL,$message); //pGnurl
	fputs($gbfp,"{$SENDID}\n{$RETURNID}\n{$SUBJ}\n{$message}");
	pclose($gbfp);
        //remove previous log file 
	unlink($LLOGFILE);
	$cnt=0;
	$batpt=popen($BATCHP,"w");
	if ($batpt)
	{
	   for ($i=0;$i<count($all);$i=$i+1) //for each user
	   if (substr($all[$i],0,2)!="--") //ohqqlq
		{
		  if ($cnt>=$MAIL_NUM)
		  {
			pclose($batpt);
			$batpt=popen($BATCHP,"w");
			$cnt=0;
		  }
		  $all[$i]=trim($all[$i]);
		  $ai=$i+1;
		  fputs($batpt,"$SENDP $USER $all[$i] $ai &\n");
		  $cnt=$cnt+1;
		}
	   for ($i=0;$i<count($gball);$i=$i+1) //for each user
	   if (substr($gball[$i],0,2)!="--") //ohqqlq
		{
		  if ($cnt>=$MAIL_NUM)
		  {
			pclose($batpt);
			$batpt=popen($BATCHP,"w");
			$cnt=0;
		  }
		  $gball[$i]=trim($gball[$i]);
		  $ai=$i+1;
		  fputs($batpt,"$GBSENDP $USER $gball[$i] $ai > /dev/null 2> /dev/null &\n");
		  $cnt=$cnt+1;
		}
	   pclose($batpt);
	}
	else echo "} $BATCHP ~I<br>\n";
 }
 else
 {
	echo "Lk} $outfile!<br>\n";
 }
 /**************** Oɶ *************/
 $fp=fopen($LOGFILE,"a");
 $DAYTIME=date("Y/m/d H:i:s");
 $MSG="$DAYTIME $PHP_AUTH_USER oe $USER qlI\n"; 
 fputs($fp,$MSG);
 fclose($fp);
?>
oe<br>

==> epaper-2.2.tgz: epaper-2.2/mailout.php <==
<?php
 require("config.php");
 require("auth.php");
 $all=file($PAPERFILE);//ŪiҦɮ
 $gball=file($GBPAPERFILE);//ŪiҦɮ
 /*****oѼ ********/
 $USER=$_REQUEST["USER"];
 $RETURNID=$_REQUEST["RETURNID"];
 $SUBJ=$_REQUEST["SUBJ"];
 $sfile=(int) $_REQUEST["sfile"];
 $message=$_REQUEST["message"];
 $userfile=$_FILES['userfile']['tmp_name'];
 /**************** O}lɶ *************/
 $fp=fopen($LOGFILE,"a");
 $DAYTIME=date("Y/m/d H:i:s");
 $MSG="$DAYTIME $PHP_AUTH_USER }loe $USER qlI\n"; 
 fputs($fp,$MSG);
 fclose($fp);
 $outfile=$PAPERBASEDIR.$USER."/MSG";
 $gboutfile=$AUTOCONV." > ".$PAPERBASEDIR.$USER."/GBMSG";
 /*********BzH **********************/
 if ($sfile==1 && is_readable($userfile)) 
   {
	$userfile_name=$_FILES['userfile']['name'];
	echo "HX $userfile_name <br>";
	$message=join("",file($userfile));
   }
 if (strlen(trim($message))==0)
  {
	echo "~ISeI<br>\n";
	exit;
  }
  $message=str_replace("\"","\"",$message);

 /********* }leH ********************/
 $fp=fopen($outfile,"w");
 $gbfp=popen($gboutfile,"w");
 if ($fp)
 {
	fputs($fp,"{$SENDID}\n{$RETURNID}\n{$SUBJ}\n{$message}");
	fclose($fp);
	/****XGBX******/
	$message=str_replace($MAIN_URL,$GB_URL,$message); //pGnurl
	$message=str_replace("charset=big5","charset=gb2312",$message); //GBXܧ
	fputs($gbfp,"{$SENDID}\n{$RETURNID}\n{$SUBJ}\n{$message}");
	pclose($gbfp);
        //remove previous log file 
	unlink($LLOGFILE);
	$cnt=0;
	$batpt=popen($BATCHP,"w");
	if ($batpt)
	{
	   for ($i=0;$i<count($all);$i=$i+1) //for each user
	   if (substr($all[$i],0,2)!="--") //ohqqlq
		{
		  if ($cnt>=$MAIL_NUM)
		  {
			pclose($batpt);
			$batpt=popen($BATCHP,"w");
			$cnt=0;
		  }
		  $all[$i]=trim($all[$i]);
		  $ai=$i+1;
		  fputs($batpt,"$SENDP $USER $all[$i] $ai > /dev/null 2> /dev/null &\n");
		  $cnt=$cnt+1;
		}
	   for ($i=0;$i<count($gball);$i=$i+1) //for each user
	   if (substr($gball[$i],0,2)!="--") //ohqqlq
		{
		  if ($cnt>=$MAIL_NUM)
		  {
			pclose($batpt);
			$batpt=popen($BATCHP,"w");
			$cnt=0;
		  }
		  $gball[$i]=trim($gball[$i]);
		  $ai=$i+1;
		  fputs($batpt,"$GBSENDP $USER $gball[$i] $ai > /dev/null 2> /dev/null &\n");
		  $cnt=$cnt+1;
		}
	   pclose($batpt);
	}
	else echo "} $BATCHP ~I<br>\n";
 }
 else
 {
	echo "Lk} $outfile!<br>\n";
 }
 /**************** Oɶ *************/
 $fp=fopen($LOGFILE,"a");
 $DAYTIME=date("Y/m/d H:i:s");
 $MSG="$DAYTIME $PHP_AUTH_USER oe $USER qlI\n"; 
 fputs($fp,$MSG);
 fclose($fp);
?>
oe<br>
